--
-- Current Database: `opmon`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `opmon` /*!40100 DEFAULT CHARACTER SET latin1 */;
USE `opmon`;

CREATE TABLE host_comment (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	entry_time datetime,	
	author_name varchar(256) DEFAULT '',  
	comment_data text,
	persistent int(10) NOT NULL default '0',
	source int(10) NOT NULL default '0',  
	entry_type  int(10) NOT NULL default '0',
	expires int(10) NOT NULL default '0',
	expire_time datetime,
	comment_id int(10) NOT NULL default '0',
	PRIMARY KEY  (comment_id),
	KEY host_comment_1_idx (host_id,`timestamp`),
	KEY host_comment_2_idx (author_name,host_id,`timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_comment (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	entry_time datetime,	
	author_name varchar(256) DEFAULT '',  
	comment_data text,
	persistent int(10) NOT NULL default '0',
	source int(10) NOT NULL default '0',  
	entry_type  int(10) NOT NULL default '0',
	expires int(10) NOT NULL default '0',
	expire_time datetime,
	comment_id int(10) NOT NULL default '0',
	PRIMARY KEY  (comment_id),
	KEY service_comment_1_idx (host_id,service_id,`timestamp`),
	KEY service_comment_2_idx (author_name,host_id,service_id,`timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE host_downtime (
	type int(10) NOT NULL default '0',
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	 host_id int(11) unsigned,
	entry_time datetime,
	author_name varchar(256) DEFAULT '',
	comment_data text,
	start_time datetime NOT NULL,
	end_time datetime NOT NULL,
	fixed int(10) NOT NULL default '0',
	duration int(10) NOT NULL default '0',
	triggered_by int(10) NOT NULL default '0',
	downtime_id int(10) NOT NULL default '0',
	PRIMARY KEY (`timestamp`, type, host_id, author_name, downtime_id),
	KEY host_downtime_1_idx (`timestamp`, host_id, downtime_id),
	KEY host_downtime_2_idx (start_time, end_time, host_id),
	KEY host_downtime_3_idx (end_time, start_time, host_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_downtime (
	type int(10) NOT NULL default '0',
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	entry_time datetime,
	author_name varchar(256) DEFAULT '',
	comment_data text,
	start_time datetime NOT NULL,
	end_time datetime NOT NULL,
	fixed int(10) NOT NULL default '0',
	duration int(10) NOT NULL default '0',
	triggered_by int(10) NOT NULL default '0',
	downtime_id int(10) NOT NULL default '0',
	PRIMARY KEY (`timestamp`, type, host_id, author_name, downtime_id),
	KEY service_downtime_1_idx (`timestamp`, host_id, downtime_id),
	KEY service_downtime_2_idx (start_time, end_time, host_id),
	KEY service_downtime_3_idx (end_time, start_time, host_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE host_notification (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	contact_name varchar(128) NOT NULL default '',
	command_name varchar(256) NOT NULL default '',
	command_args text,
	reason_type int(10) NOT NULL default '0',
	state int(10) NOT NULL default '0',
	output text,
	ack_author varchar(256) NOT NULL default '',
	ack_data text,
	escalated int(10) NOT NULL default '0',
	start_time datetime,
	end_time datetime,
	PRIMARY KEY (`timestamp`, host_id, contact_name, command_name, reason_type, state),
	KEY host_notification_1_idx (host_id, contact_name, `timestamp`),
	KEY host_notification_2_idx (state, contact_name, `timestamp`),
	KEY host_notification_3_idx (reason_type, state, contact_name, `timestamp`),
	KEY host_notification_4_idx (command_name, contact_name, host_id, `timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_notification (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	contact_name varchar(128) NOT NULL default '',
	command_name varchar(256) NOT NULL default '',
	command_args text,
	reason_type int(10) NOT NULL default '0',
	state int(10) NOT NULL default '0',
	output text,
	ack_author varchar(256) NOT NULL default '',
	ack_data text,
	escalated int(10) NOT NULL default '0',
	start_time datetime,
	end_time datetime,
	PRIMARY KEY (`timestamp`, host_id, contact_name, command_name, reason_type, state),
	KEY service_notification_1_idx (host_id, service_id, contact_name, `timestamp`),
	KEY service_notification_2_idx (state, contact_name, `timestamp`),
	KEY service_notification_3_idx (reason_type, state, contact_name, `timestamp`),
	KEY service_notification_4_idx (command_name, contact_name, host_id, `timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE host_state_change (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	state int(10) NOT NULL default '0',
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	max_attempts int(10) NOT NULL default '0',
	output text,
	PRIMARY KEY (`timestamp`, host_id, state, state_type, current_attempt),
	KEY host_state_change_1_idx (host_id, `timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_state_change (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	state int(10) NOT NULL default '0',
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	max_attempts int(10) NOT NULL default '0',
	output text,
	PRIMARY KEY (`timestamp`, host_id, service_id, state, state_type, current_attempt),
	KEY service_state_change_1_idx (host_id, service_id, `timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE host_flapping (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	comment_id int(10) NOT NULL default '0',
	percent_change float,
	high_threshold float,
	low_threshold float,
	PRIMARY KEY (`timestamp`, host_id, type),
	KEY host_flapping_1_idx (host_id, `timestamp`),
	KEY host_flapping_2_idx (comment_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_flapping (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	comment_id int(10) NOT NULL default '0',
	percent_change float,
	high_threshold float,
	low_threshold float,
	PRIMARY KEY (`timestamp`, host_id, service_id, type),
	KEY service_flapping_1_idx (host_id, service_id, `timestamp`),
	KEY service_flapping_2_idx (comment_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE external_command (
	`timestamp` datetime NOT NULL default '0000-00-00 00:00:00',
	command_type int(10) NOT NULL default '0',
	entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	command_string varchar(512) NOT NULL default '',
	command_args varchar(512) NOT NULL default '',
	KEY external_command_1_idx (`timestamp`),
	KEY external_command_2_idx (command_type,`timestamp`),
	KEY external_command_3_idx (command_string),
	KEY external_command_4_idx (command_args),
	KEY external_command_5_idx (`timestamp`,command_type,command_string,command_args)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE host_status (
	host_id int(11) unsigned,
	problem_has_been_acknowledged int(10) NOT NULL default '0',
	acknowledgement_type int(10) NOT NULL default '0',
	check_type int(10) NOT NULL default '0',
	current_state int(10) NOT NULL default '0',
	last_state int(10) NOT NULL default '0',
	last_hard_state int(10) NOT NULL default '0',
	plugin_output text,
	long_plugin_output text,
	perf_data text,
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	latency float,
	execution_time float,
	is_executing int(10) NOT NULL default '0',
	check_options int(10) NOT NULL default '0',
	notifications_enabled int(10) NOT NULL default '0',
	last_host_notification datetime,
	next_host_notification datetime,
	next_check datetime,
	should_be_scheduled int(10) NOT NULL default '0',
	last_check datetime,
	last_state_change datetime,
	last_hard_state_change datetime,
	last_time_up datetime,
	last_time_down datetime,
	last_time_unreachable datetime,
	has_been_checked int(10) NOT NULL default '0',
	is_being_freshened int(10) NOT NULL default '0',
	notified_on_down int(10) NOT NULL default '0',
	notified_on_unreachable int(10) NOT NULL default '0',
	current_notification_number int(10) NOT NULL default '0',
	no_more_notifications int(10) NOT NULL default '0',
	current_notification_id int(10) NOT NULL default '0',
	check_flapping_recovery_notification int(10) NOT NULL default '0',
	scheduled_downtime_depth int(10) NOT NULL default '0',
	pending_flex_downtime int(10) NOT NULL default '0',
	is_flapping int(10) NOT NULL default '0',
	flapping_comment_id int(10) NOT NULL default '0',
	percent_state_change float,
	total_services int(10) NOT NULL default '0',
	total_service_check_interval int(10) NOT NULL default '0',
	modified_attributes int(10) NOT NULL default '0',
	PRIMARY KEY (host_id),
	KEY host_status_1_idx (next_check, host_id),
	KEY host_status_2_idx (last_check, host_id),
	KEY host_status_3_idx (last_state_change, host_id),
	KEY host_status_4_idx (last_hard_state_change, host_id),
	KEY host_status_5_idx (last_time_up, host_id),
	KEY host_status_6_idx (last_time_down, host_id),
	KEY host_status_7_idx (last_time_unreachable, host_id),
	KEY host_status_8_idx (latency, host_id),
	KEY host_status_9_idx (execution_time, host_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE service_status (
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	problem_has_been_acknowledged int(10) NOT NULL default '0',
	acknowledgement_type int(10) NOT NULL default '0',
	host_problem_at_last_check int(10) NOT NULL default '0',
	check_type int(10) NOT NULL default '0',
	current_state int(10) NOT NULL default '0',
	last_state int(10) NOT NULL default '0',
	last_hard_state int(10) NOT NULL default '0',
	plugin_output text,
	long_plugin_output text,
	perf_data text,
	state_type int(10) NOT NULL default '0',
	next_check datetime,
	should_be_scheduled int(10) NOT NULL default '0',
	last_check datetime,
	current_attempt int(10) NOT NULL default '0',
	current_event_id int(10) NOT NULL default '0',
	last_event_id int(10) NOT NULL default '0',
	current_problem_id int(10) NOT NULL default '0',
	last_problem_id int(10) NOT NULL default '0',
	last_notification datetime,
	next_notification datetime,
	no_more_notifications int(10) NOT NULL default '0',
	check_flapping_recovery_notification int(10) NOT NULL default '0',
	last_state_change datetime,
	last_hard_state_change datetime,
	last_time_ok datetime,
	last_time_warning datetime,
	last_time_unknown datetime,
	last_time_critical datetime,
	has_been_checked int(10) NOT NULL default '0',
	is_being_freshened int(10) NOT NULL default '0',
	notified_on_unknown int(10) NOT NULL default '0',
	notified_on_warning int(10) NOT NULL default '0',
	notified_on_critical int(10) NOT NULL default '0',
	current_notification_number int(10) NOT NULL default '0',
	current_notification_id int(10) NOT NULL default '0',
	latency float,
	execution_time float,
	is_executing int(10) NOT NULL default '0',
	check_options int(10) NOT NULL default '0',
	scheduled_downtime_depth int(10) NOT NULL default '0',
	pending_flex_downtime int(10) NOT NULL default '0',
	is_flapping int(10) NOT NULL default '0',
	flapping_comment_id int(10) NOT NULL default '0',
	percent_state_change float,
	modified_attributes int(10) NOT NULL default '0',
	PRIMARY KEY (host_id, service_id),
	KEY service_status_1_idx (next_check, host_id, service_id),
	KEY service_status_2_idx (last_check, host_id, service_id),
	KEY service_status_3_idx (last_state_change, host_id, service_id),
	KEY service_status_4_idx (last_hard_state_change, host_id, service_id),
	KEY service_status_5_idx (last_time_ok, host_id, service_id),
	KEY service_status_6_idx (last_time_warning, host_id, service_id),
	KEY service_status_7_idx (last_time_unknown, host_id, service_id),
	KEY service_status_8_idx (last_time_critical, host_id, service_id),
	KEY service_status_9_idx (latency, host_id, service_id),
	KEY service_status_10_idx (execution_time, host_id, service_id)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE `history`;
DROP TABLE `history_list`;

ALTER TABLE `informacoes` RENAME TO `informacoes_old`;
CREATE TABLE `informacoes` (
	host_id int(11) unsigned,
	`username` varchar(255) default NULL,
	`date` datetime default NULL,
	`description` varchar(255) default NULL,
	`address` varchar(255) default NULL,
	`city` varchar(255) default NULL,
	`state` varchar(100) default NULL,
	`country` varchar(255) default NULL,
	`patrimonio` varchar(255) default NULL,
	`machine` varchar(255) default NULL,
	`contact1` varchar(255) default NULL,
	`email1` varchar(255) default NULL,
	`phone1` varchar(255) default NULL,
	`cel1` varchar(255) default NULL,
	`contact2` varchar(255) default NULL,
	`email2` varchar(255) default NULL,
	`phone2` varchar(255) default NULL,
	`cel2` varchar(255) default NULL,
	`contact3` varchar(255) default NULL,
	`email3` varchar(255) default NULL,
	`phone3` varchar(255) default NULL,
	`cel3` varchar(255) default NULL,
	`contact4` varchar(255) default NULL,
	`email4` varchar(255) default NULL,
	`phone4` varchar(255) default NULL,
	`cel4` varchar(255) default NULL,
	`provider` varchar(255) default NULL,
	`downstream` varchar(255) default NULL,
	`upstream` varchar(255) default NULL,
	`provider_user` varchar(255) default NULL,
	`provider_password` varchar(255) default NULL,
	`contract` varchar(255) default NULL,
	`contract_provider` varchar(255) default NULL,
	`modemop` varchar(255) default NULL,
	`modem` varchar(255) default NULL,
	`obs` text,
	`hw_descr` text,
	`voip1` varchar(100) default NULL,
	`voip2` varchar(100) default NULL,
	`voip3` varchar(100) default NULL,
	`voip4` varchar(100) default NULL,
	`lan_device` varchar(100) default NULL,
	`iplan` varchar(100) default NULL,
	`iplan_mask` varchar(100) default NULL,
	`link_type` varchar(100) default NULL,
	`link_device` varchar(100) default NULL,
	`link_ip` varchar(100) default NULL,
	`link_ip_mask` varchar(100) default NULL,
	`link_dg` varchar(100) default NULL,
	`link_type2` varchar(100) default NULL,
	`link_device2` varchar(100) default NULL,
	`link_ip2` varchar(100) default NULL,
	`link_dg2` varchar(100) default NULL,
	`provider2` varchar(100) default NULL,
	`downstream2` varchar(100) default NULL,
	`upstream2` varchar(100) default NULL,
	`provider_user2` varchar(100) default NULL,
	`provider_password2` varchar(100) default NULL,
	`contract2` varchar(100) default NULL,
	`contract_provider2` varchar(100) default NULL,
	`modemop2` varchar(100) default NULL,
	`modem2` varchar(100) default NULL,
	`link_type3` varchar(100) default NULL,
	`link_device3` varchar(100) default NULL,
	`link_ip3` varchar(100) default NULL,
	`link_dg3` varchar(100) default NULL,
	`provider3` varchar(100) default NULL,
	`downstream3` varchar(100) default NULL,
	`upstream3` varchar(100) default NULL,
	`provider_user3` varchar(100) default NULL,
	`provider_password3` varchar(100) default NULL,
	`contract3` varchar(100) default NULL,
	`contract_provider3` varchar(100) default NULL,
	`modemop3` varchar(100) default NULL,
	`modem3` varchar(100) default NULL,
	`link_ip_mask3` varchar(100) default NULL,
	`link_ip_mask2` varchar(100) default NULL,
	`ssh_port` int(11) default '54978',
	`https_port` int(11) default '443',
	`iplan_dg` varchar(100) default NULL,
	PRIMARY KEY  (`host_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE `users` (
	`username` varchar(255) NOT NULL default '',
	`data` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	`permition` int(11) default NULL,
	PRIMARY KEY  (`username`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `opperf` /*!40100 DEFAULT CHARACTER SET latin1 */;
USE `opperf`;

CREATE TABLE `service_metric` (
	`metric_id` int(11) NOT NULL auto_increment,
	`host_id` int(11) NOT NULL default '0',
	`service_id` int(11) NOT NULL default '0',
	`metric` varchar(75) NOT NULL default '',
	`unit` varchar(25) default NULL,
	`value_max` float default NULL,
	`value_min` float default NULL,
	PRIMARY KEY  (`host_id`,`service_id`,`metric`),
	KEY `metric_id` (`metric_id`),
	KEY `host_id` (`host_id`,`service_id`,`metric`),
	KEY `metric` (`metric`,`host_id`,`service_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1


